#ifndef SYMFONIEVOLUMESLIDER_H
#define SYMFONIEVOLUMESLIDER_H

#include <QWidget>
#include <phonon>

class SymfonieVolumeSlider : public Phonon::VolumeSlider
{
Q_OBJECT
public:
    explicit SymfonieVolumeSlider(Phonon::AudioOutput*, QWidget *parent = 0);

signals:

public slots:

protected:
   // void paintEvent(QPaintEvent *event);



};

#endif // SYMFONIEVOLUMESLIDER_H
